@@ -130,7 +130,7 @@ class ConfigWrapper(object):
         ...     cursor = pgconn.cursor()
         ...     cursor.execute("update ...")
 
-        ]and the transaction will be committed when you leave the with
+        and the transaction will be committed when you leave the with
         block.
 
         """
@@ -202,39 +202,19 @@ class ConfigWrapper(object):
         psycopg2.extensions.register_type(psycopg2.extensions.UNICODEARRAY)
 
         if register_composite_types:
-            self.register_horsemeat_composite_types(pgconn)
-            log.debug('Registered horsemeat composite types')
             self.register_composite_types(pgconn)
-            log.debug('Registered projects composite types')
+            log.debug('Registered project composite types')
 
         return pgconn
 
-    # Make an alias because Matt can't remember stuff good.
+    # Make aliases because Matt can't remember stuff good.
     create_postgresql_connection = make_database_connection
+    make_postgresql_connection = make_database_connection
 
     @abc.abstractproperty
     def register_composite_types(self, pgconn):
-
         raise NotImplementedError
 
-
-    def register_horsemeat_composite_types(self, pgconn):
-
-        from horsemeat.model.user import PersonFactory
-
-        psycopg2.extras.register_composite('people', pgconn,
-            factory=PersonFactory)
-
-        from horsemeat.model.session import SessionFactory
-
-        psycopg2.extras.register_composite('horsemeat_sessions', pgconn,
-          factory=SessionFactory)
-
-        log.info('Just registered composite types in psycopg2')
-
-        return pgconn
-
-
     def configure_logging(self, process_type='default'):
 
         if 'logging' not in self.config_dictionary:
